function [x, Flag,R2] = P3_LowAIDS(BS,R,S,Win,IV,SKUP)
% Obtain lower stage estimates
% R=1 if using regional dummies; S=1 if using seasonal dummies;
% Win=1 if using winter dummies

SW=BS(:,1); SLP=BS(:,2); SPI=BS(:,3);SLXP=BS(:,4); Region=BS(:,6:8);
Season=BS(:,10:11); Winter=BS(:,11);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% First Stage: Instrument LnP and LnXP 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
End=[SLP;SLXP(1:96)];
[LnPHat LnP_MHat LnP_FHat LnP_DHat LnXPHat R2] = P4_IV(End,IV,SKUP);
DataMatrix = zeros(672,6);
DataMatrix = [ones(672,1), LnPHat, LnP_MHat, LnP_FHat, LnP_DHat, LnXPHat];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Define constraints: Add-Up, Homogeneity, Symmetry
% The Parameter vector: Alpha_i, GammaP_i, GammaM_i, GammaF_i,
% GammaD_i, Beta_i, plus region dummies (E_i,W_i,S_i) & season
% (M_i,Wn_i), where GammaP_i is the gamma coef for own price, GammaM_i is
% the gamma coef for price of the product with the same molecule but
% produced by firms with different nationalities, GammaF_i is the gamma
% coef for prices of foreign prod, GammaD_i is the gamma coef for prices of
% domestic products.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[Aeq, beq] = P5_DummyCon(R, S, Win);   

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Define the constraint matrix, estimate using fitted LnPCur & LnXP
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
options = optimset('LargeScale','Off');
if R==1 & S==0 & Win==0
    x_0 = zeros(63,1);                  %Using regional dummies alone
    C = zeros(672,63);
    for i = 1: 7;
        C(1+(i-1)*96:i*96,1+(i-1)*6:i*6) = DataMatrix(1+(i-1)*96:i*96 ,:);
        C(1+(i-1)*96:i*96,43+(i-1)*3:42+i*3) = Region(1+(i-1)*96:i*96,:);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, SW, [],[],Aeq, beq,[],[],x_0,options);
elseif R==1 & S==0 & Win==1
    x_0 = zeros(70,1);                  %Using regional and Winter dummy
    C = zeros(672,70);
    for i = 1: 7;
        C(1+(i-1)*96:i*96,1+(i-1)*6:i*6) = DataMatrix(1+(i-1)*96:i*96 ,:);
        C(1+(i-1)*96:i*96,43+(i-1)*3:42+i*3) = Region(1+(i-1)*96:i*96,:);
        C(1+(i-1)*96:i*96,63+i) = Winter(1+(i-1)*96:i*96,:);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, SW, [],[],Aeq, beq,[],[],x_0,options);
elseif R==1 & S==1 & Win==0
    x_0 = zeros(77,1);                  %Using regional and seasonal dummies 
    C = zeros(672,77);
    for i = 1: 7;
        C(1+(i-1)*96:i*96,1+(i-1)*6:i*6) = DataMatrix(1+(i-1)*96:i*96 ,:);
        C(1+(i-1)*96:i*96,43+(i-1)*3:42+i*3) = Region(1+(i-1)*96:i*96,:);
        C(1+(i-1)*96:i*96,64+(i-1)*2:63+i*2) = Season(1+(i-1)*96:i*96,:);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, SW, [],[],Aeq, beq,[],[],x_0,options);
elseif R==0 & S==0 & Win==0
    x_0 = zeros(42,1);                  %No dummies
    C = zeros(672,42);
    for i = 1: 7;
        C(1+(i-1)*96:i*96,1+(i-1)*6:i*6) = DataMatrix(1+(i-1)*96:i*96 ,:);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, SW, [],[],Aeq, beq,[],[],x_0,options);
end;