function [x, Flag] = P3_LowerAIDS_OLS(BS,R,S,Win)
% Obtain lower stage estimates

SW=BS(:,1); SLP=BS(:,2); SPI=BS(:,3);SLXP=BS(:,4); Region=BS(:,6:8);
Season=BS(:,10:11); 

LnP = BS(:,2); LnXP = BS(:,4);
LnP_M = zeros(672,1);
LnP_F = zeros(672,1);
LnP_D = zeros(672,1);

LnP_M(1:288) = LnP(289:576);
LnP_M(289:576) = LnP(1:288);

Ptmp = zeros(96,7);
Ptmp(:) = LnP;
Ptmp = Ptmp';                       % 7 by 96, each column refers to one period
LnFTot = sum(Ptmp(1:3,:))';         % A 96 by 1 column vector; the sum of foreign drug prices 
                                    %   for each period
LnFTotL = repmat(LnFTot,3,1);                                    
LnP_F(1:288) = LnFTotL - LnP(1:288);
LnP_F(289:576) = LnP_F(1:288);
LnP_F(577:end) = LnFTot;

LnDTot = sum(Ptmp(4:7,:))';
LnDTotL = repmat(LnDTot,4,1);
LnP_D(289:end) = LnDTotL - LnP(289:end);
LnP_D(1:288) = LnP_D(289:576);

DataMatrix = zeros(672,6);
DataMatrix = [ones(672,1), LnP, LnP_M, LnP_F, LnP_D, LnXP];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Define constraints: Add-Up, Homogeneity, Symmetry
% The Parameter vector: Alpha_i, GammaP_i, GammaM_i, GammaF_i,
% GammaD_i, Beta_i, plus region dummies (E_i,W_i,S_i) & season
% (M_i,Wn_i)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[Aeq, beq] = P5_DummyCon(R, S, Win);   %Using regional dummies alone

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Define the Constraint Matrix
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
options = optimset('LargeScale','Off');
if R==1 & S==0 & Win==0
    x_0 = zeros(63,1);                 
    C = zeros(672,63);
    for i = 1: 7;
        C(1+(i-1)*96:i*96,1+(i-1)*6:i*6) = DataMatrix(1+(i-1)*96:i*96 ,:);
        C(1+(i-1)*96:i*96,43+(i-1)*3:42+i*3) = Region(1+(i-1)*96:i*96,:);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, SW, [],[],Aeq, beq,[],[],x_0,options);
elseif R==1 & S==0 & Win==1
    x_0 = zeros(70,1);               
    C = zeros(672,70);
    for i = 1: 7;
        C(1+(i-1)*96:i*96,1+(i-1)*6:i*6) = DataMatrix(1+(i-1)*96:i*96 ,:);
        C(1+(i-1)*96:i*96,43+(i-1)*3:42+i*3) = Region(1+(i-1)*96:i*96,:);
        C(1+(i-1)*96:i*96,63+i) = Winter(1+(i-1)*96:i*96,1);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, SW, [],[],Aeq, beq,[],[],x_0,options);
elseif R==1 & S==1 & Win==0
    x_0 = zeros(77,1);            
    C = zeros(672,77);
    for i = 1: 7;
        C(1+(i-1)*96:i*96,1+(i-1)*6:i*6) = DataMatrix(1+(i-1)*96:i*96 ,:);
        C(1+(i-1)*96:i*96,43+(i-1)*3:42+i*3) = Region(1+(i-1)*96:i*96,:);
        C(1+(i-1)*96:i*96,64+(i-1)*2:63+i*2) = Season(1+(i-1)*96:i*96,:);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, SW, [],[],Aeq, beq,[],[],x_0,options);
elseif R==0 & S==0 & Win==0
    x_0 = zeros(42,1);           
    C = zeros(672,42);
    for i = 1: 7;
        C(1+(i-1)*96:i*96,1+(i-1)*6:i*6) = DataMatrix(1+(i-1)*96:i*96 ,:);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, SW, [],[],Aeq, beq,[],[],x_0,options);
end;