function [Aeq, beq] = P5_DummyCon(R, S, Win)
% Define sum-up, homogeneity, and symmetry constraints for the lower stage
% estimation

% With regional dummies, the parameter vector is: alpha_i, gammap_i, 
%   gammam_i, gammaf_i, gammad_i, beta_i for all 7 groups followed by E_i,
%   W_i, S_i, for all 7 groups
% With seasonal dummies, the parameter vector is: alpha_i, gammap_i, 
%   gammam_i, gammaf_i, gammad_i, beta_i for all 7 groups followed by M_i,
%   Wn_i, for all 7 groups

% R=1 if using regional dummies, S=1 if using Seasonaly dummies
% Win=1 if using Winter dummy

if R == 1 & S == 0 & Win==0
    Aeq = zeros(27,63);
elseif R == 0 & S == 1 & Win==0
    Aeq = zeros(26,56);
elseif R==1 & S==1 & Win==0
    Aeq = zeros(29,77);
elseif R==0 & S==0 & Win==0
    Aeq = zeros(24,42);
elseif R==1 & S==0 & Win==1
    Aeq = zeros(28,70);
end;
    % Add up constraint part one: sum_i(alpha_i) = 1
    for i = 1: 7;
        Aeq(1,1+(i-1)*6) = 1;
    end;    

    % Add up constraints part two: sum_i(gamma_ij)=0 (it is the same as
    %   Homogeneity constraint sum_j(gamma_ij)=0 due to symmetry) 
    for i = 1:6;
        Aeq(1+i,2+(i-1)*6:5+(i-1)*6) = [1 1 2 3];
    end;
    Aeq(8,2+36:5+36) = [1 0 3 3];       % Group 7 doesn't have lnP_M

    % Symmetry part one: gamma_m1 = gamma_m4,...,gamma_m3 = gamma_m6
    for i = 1:3;
        Aeq(8+i, 3+(i-1)*6) = 1;
        Aeq(8+i, 21+(i-1)*6) = -1;
    end;    

    % Symmetry part two: gamma_f1 = gamma_f2 = gamma_f3
    Aeq(12:13,4) = 1;
    for i = 1:2;    
        Aeq(11+i, 10+(i-1)*6) = -1;
    end;

    % Symmetry part three: gamma_d1 = gamma_d2 = gamma_d3 = gamma_f4 =...= gamma_f7
    Aeq(14:19,5)=1;
    for i = 1:2;
        Aeq(13+i, 11+(i-1)*6) = -1;
    end;
    for i = 1:4;
        Aeq(15+i, 22+(i-1)*6) = -1;
    end;

    % Symmetry part four: gamma_d4 = gamma_d5 = ... = gamma_d7
    Aeq(20:22, 23) = 1;
    for i = 1:3;
        Aeq(19+i,29+(i-1)*6) = -1;
    end;

    % Add up constraint part two: sum_i(beta_i) = 0     
    for i = 1:7;
        Aeq(23, 6+(i-1)*6) = 1;
    end;

    % Group 7 doesn't have lnP_M, so gamma_{m,7} should be 0
    Aeq(24,39) = 1;

    % Add-up constrant part three: for dummies
if R == 1 & S == 0 & Win==0
    Aeq(25, 43:3:63) = 1;
    Aeq(26, 44:3:63) = 1;
    Aeq(27, 45:3:63) = 1;
    beq = zeros(27,1);
elseif R == 0 & S == 1 & Win==0
    Aeq(25, 43:2:56) = 1;
    Aeq(26, 44:2:56) = 1;
    beq = zeros(26,1);
elseif R==1 & S==1 & Win==0
    Aeq(25, 43:3:63) = 1;
    Aeq(26, 44:3:63) = 1;
    Aeq(27, 45:3:63) = 1;
    Aeq(28, 64:2:77) = 1;
    Aeq(29, 65:2:77) = 1;
    beq = zeros(29,1);
elseif R==0 & S==0 & Win==0
    beq = zeros(24,1);
elseif R==1 & S==0 & Win==1
    Aeq(25, 43:3:63) = 1;
    Aeq(26, 44:3:63) = 1;
    Aeq(27, 45:3:63) = 1;
    Aeq(28, 64:70) = 1;
    beq = zeros(28,1);
end;
        
% Define the right hand side of the linear constraint
beq(1,1) = 1;
