function [TW,TLP,TPI,TLXP] = P6_UpInitial(BS,R,S,Win)
% Obtain Upper stage starting point for Counter-factual
% BS is the bootstrap sample
% R,S,Win are dummies: R=1 if using regional dummies, S=1 if using seasonal
% dummies, Win=1 if using winter dummies
% TW, TLP, TPI, TLXP are the average revenue share, log of product price,
%   price index, and total anti-biotics expenditure observed in the sample

if R==1 & S==0 & Win==0
    TW=zeros(32,1); TLP=zeros(32,1); TPI=zeros(4,1); TLXP=zeros(4,1);
    for i=1:8
        tmp = BS((i-1)*96+1:i*96,:);
        tw = tmp(:,1);tp=tmp(:,2);tpi=tmp(:,3);txp=tmp(:,4);
        for k=1:4
            TW((k-1)*8+i)=mean(tw(tmp(:,k+4)==1));
            TLP((k-1)*8+i) =mean(tp(tmp(:,k+4)==1));
            TPI(k)=mean(tpi(tmp(:,k+4)==1));
            TLXP(k)=mean(txp(tmp(:,k+4)==1));
        end;
    end;
            
elseif R==1 & S==0 & Win==1
    TW=zeros(64,1); TLP=zeros(64,1); TPI=zeros(8,1); TLXP=zeros(8,1);
    for i=1:8
        tmp = BS((i-1)*96+1:i*96,:);
        tw = tmp(:,1);tp=tmp(:,2);tpi=tmp(:,3);txp=tmp(:,4);
        for k=1:4
            TW((k-1)*8+i)=mean(tw(tmp(:,k+4)==1 & tmp(:,11)==0));
            TLP((k-1)*8+i) =mean(tp(tmp(:,k+4)==1 & tmp(:,11)==0));
            TPI(k)=mean(tpi(tmp(:,k+4)==1 & tmp(:,11)==0));
            TLXP(k)=mean(txp(tmp(:,k+4)==1 & tmp(:,11)==0));

            TW((k+3)*8+i)=mean(tw(tmp(:,k+4)==1 & tmp(:,11)==1));
            TLP((k+3)*8+i) =mean(tp(tmp(:,k+4)==1 & tmp(:,11)==1));
            TPI(k+4)=mean(tpi(tmp(:,k+4)==1 & tmp(:,11)==1));
            TLXP(k+4)=mean(txp(tmp(:,k+4)==1 & tmp(:,11)==1));
        end;
    end;
elseif R==0 & S==0 & Win==0
    TW=zeros(8,1); TLP=zeros(8,1); 
    for i=1:8
        tmp = BS((i-1)*96+1:i*96,:);
        TW(i)=mean(tmp(:,1));
        TLP(i)=mean(tmp(:,2));
    end;
    TPI=mean(BS(1:96,3));
    TLXP=mean(BS(1:96,4));
elseif R==1 & S==1 & Win==0
    TW=zeros(8*12,1); TLP=zeros(8*12,1); TPI=zeros(12,1); TLXP=zeros(12,1);
    for i=1:8
        tmp = BS((i-1)*96+1:i*96,:);
        tw = tmp(:,1);tp=tmp(:,2);tpi=tmp(:,3);txp=tmp(:,4);
        for k=1:4
            for j=1:3
                TW((k-1)*24+(j-1)*8+i)=mean(tw(tmp(:,k+4)==1&tmp(:,j+8)==1));
                TLP((k-1)*24+(j-1)*8+i)=mean(tp(tmp(:,k+4)==1&tmp(:,j+8)==1));
                TPI((k-1)*3+j)=mean(tpi(tmp(:,k+4)==1&tmp(:,j+8)==1));
                TLXP((k-1)*3+j)=mean(txp(tmp(:,k+4)==1&tmp(:,j+8)==1));
            end;
        end;
    end;
    
end;

