diary TRIPS_Appen.out
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The program that estimates other AIDS specifications as in the appendix
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear; format short g;

load AIDSData.mat                
%'TD' Contains data of the anti-biotics sub-segments, used for the 
% Top-level demand estimation: Segment Revenue Share, Log of Segment Price,
% Price Index for the Top Level, Log of per capita price index deflated 
% expenditure on anti-biotics

%'SD' contains data of the product groups in the Quinolone segment, used 
% for the second-level demand estimation: Product revenue share, log
% of the product price, price index for the lower level, log of per capita
% price index deflated expenditure on Quinolones; regional dummies: North,
% East, West, South; Seasonal dummies: Summer, Monsoon, Winter; the number
% of SKU in each product group; prices for the top SKUs; log of total expenditure 
% on anti-biotics

%'State' contains the random generator used for the paper
%'State_Appen' contains the random generator used for the appendix
%   specification

rand('state',State_Appen)         %Use the same random generator as in the paper

BST=300;        %Generate 300 Bootstrap samples
for j = 1:BST
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Bootstrap data
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    BS1=[]; BS2=[];
    if j == 1;                      % Obtain parameter estimate using the original sample
        BS1=TD; BS2=SD;
    else                            % for j =2:300, the bootstrap samples
        Idx = ceil( 96*rand(96,1) ); 
        for i = 1 : 8;
            Smp = TD(1+(i-1)*96:i*96,:);          % The Bootstrap sample uses the same region/period for all segment
            BS1  = [BS1;Smp(Idx,:)];                  
        end;
        for i = 1 : 7;
            Smp = SD(1+(i-1)*96:i*96,:);          % The Bootstrap sample uses the same region/period for all product group
            BS2  = [BS2;Smp(Idx,:)];                  
        end;
    end;
    
    Region=BS2(1:96,5:8); Season=BS2(1:96,9:11);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Estimation for the Upper Stage
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    TR=1;TS=0;TWin=0; %Only Region Dummy for Top level
    [TC(:,j), TFlag(j)] = P1_UpAIDS([BS1(:,1:4),repmat([Region,Season],8,1)],...
                          TR, TS, TWin);
    [TW(:,j),TLP(:,j),TPI(:,j),TLXP(:,j)] = P6_UpInitial([BS1(:,1:4),...
        repmat([Region,Season],8,1)],TR, TS, TWin);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Estimate the Lower Stage with both regional and seasonal dummies
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    SR=1;SS=1;SWin=0; %Region & Season Dummy for Low level
    SKUN = BS2(:,12); 
    tmp1=zeros(96,7); tmp1(:)=SKUN; 
    [SC1(:,j), SFlag1(j)] = P3_LowerAIDS([BS2(:,1:4),repmat([Region,Season],7,1)],...
                          SR, SS, SWin,[tmp1,Region(:,2:4),Season(:,2:3),BS2(1:96,18)],BS2(:,13:17));
    %Lower IV: 7 group SKUN, Region, Season, Antibiotics expenditure

    [SW1(:,j),SLP1(:,j),SPI1(:,j),SLXP1(:,j)] = P7_LowInitial_Season([BS2(:,1:4),...
        repmat([Region,Season],7,1)],SR, SS, SWin);
    SLX1(:,j)=SPI1(:,j)+SLXP1(:,j);
                      
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Obtain Unconditional demand elasticities for different seasons for
    % the northern region
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    r=1;
    tmp=zeros(10,8); tmp(:)=TC(1:80,j);
    TA=tmp(1,:)';
    TG=tmp(2:9,:); TB=tmp(10,:)';

    t1 = zeros(6,7); t1(:) = SC1(1:42,j);
    t2 = zeros(3,7); t2(:) = SC1(43:63,j);
    t3 = zeros(2,7); t3(:) = SC1(64:end,j);
    Coef=[t1;t2;t3]';
    for t=1:3
        if t==1
            SA=Coef(:,1);
        else
            SA=Coef(:,1)+Coef(:,t+8);
        end;
        SB = Coef(:,6); SG = P8_Gamma(Coef(:,2:5));
    
        [TLX(r,j),TA0(r,j),TU0(r,j),SA0(r,j),SU0(r,j),SEtaU1((t-1)*49+1:t*49,j),...
            MC((r-1)*7+1:r*7,j)]=P9_Base(TA,TG,TB,...
        TLP((r-1)*8+1:r*8,j),TLXP(r,j),SA,SG,SB,SLP1((t-1)*7+1:t*7,j),...
        SPI1(t,j),SLX1(t,j),SW1((t-1)*7+1:t*7,j));
    end;
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Estimate the Lower Stage with only regional dummies: OLS/No SKU Price
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    SR=1;SS=0;SWin=0; %Only Region Dummy for Low level
    [SW(:,j),SLP(:,j),SPI(:,j),SLXP(:,j)] = P7_LowInitial([BS2(:,1:4),...
        repmat([Region,Season],7,1)],SR, SS, SWin);
    SLX(:,j)=SPI(:,j)+SLXP(:,j);

    %%%%%% Estimate the Lower Stage using OLS
    [SC2(:,j), SFlag2(j)] = P3_LowerAIDS_OLS([BS2(:,1:4),repmat([Region,Season],7,1)],...
                          SR, SS, SWin);
    
    %%%%%% Estimate the lower stage without using SKU Prices in the IV
    tmp1=zeros(96,7); tmp1(:)=SKUN; 
    [SC4(:,j), SFlag4(j)] = P3_LowerAIDS_NoSKUP([BS2(:,1:4),repmat([Region,Season],7,1)],...
                          SR, SS, SWin,[tmp1,Region(:,2:4),BS2(1:96,18)]);

    %%%%%% Find Unconditional demand Elas for the OLS estimation
    t1 = zeros(6,7); t1(:) = SC2(1:42,j);
    t2 = zeros(3,7); t2(:) = SC2(43:63,j);
    Coef=[t1;t2]';
    SA = Coef(:,1) + Coef(:,8);
    SB = Coef(:,6); SG = P8_Gamma(Coef(:,2:5));
    
    [TLX(r,j),TA0(r,j),TU0(r,j),SA0(r,j),SU0(r,j),SEtaU2(:,j),...
            MC((r-1)*7+1:r*7,j)]=P9_Base(TA,TG,TB,...
        TLP((r-1)*8+1:r*8,j),TLXP(r,j),SA,SG,SB,SLP((r-1)*7+1:r*7,j),...
        SPI(r,j),SLX(r,j),SW((r-1)*7+1:r*7,j));

    %%%%%% Find Unconditional demand Elas for the IV estimation without SKU
    %%%%%% prices
    t1 = zeros(6,7); t1(:) = SC4(1:42,j);
    t2 = zeros(3,7); t2(:) = SC4(43:63,j);
    Coef=[t1;t2]';
    SA = Coef(:,1) + Coef(:,8);
    SB = Coef(:,6); SG = P8_Gamma(Coef(:,2:5));
    
    [TLX(r,j),TA0(r,j),TU0(r,j),SA0(r,j),SU0(r,j),SEtaU4(:,j),...
            MC((r-1)*7+1:r*7,j)]=P9_Base(TA,TG,TB,...
        TLP((r-1)*8+1:r*8,j),TLXP(r,j),SA,SG,SB,SLP((r-1)*7+1:r*7,j),...
        SPI(r,j),SLX(r,j),SW((r-1)*7+1:r*7,j));
end;


%%%%% Create tables A4 and A5
t=isnan(SEtaU1(1,:));
SEtaU1=SEtaU1(:,t~=1);

EtaU11 = zeros(7,7);
EtaU11(:) = SEtaU1(1:49,1);
Sd11 = zeros(7,7);
t = std(SEtaU1')';
Sd11(:) = t(1:49);

EtaU12 = zeros(7,7);
EtaU12(:) = SEtaU1(50:98,1);
Sd12 = zeros(7,7);
Sd12(:) = t(50:98);

EtaU13 = zeros(7,7);
EtaU13(:) = SEtaU1(99:end,1);
Sd13 = zeros(7,7);
Sd13(:) = t(99:end);

EtaU2 = zeros(7,7);
EtaU2(:) = SEtaU2(:,1);
Sd2 = zeros(7,7);
Sd2(:) = std(SEtaU2')';

EtaU4 = zeros(7,7);
EtaU4(:) = SEtaU4(:,1);
Sd4 = zeros(7,7);
Sd4(:) = std(SEtaU4')';

ElasSummer = zeros(14,7);
ElasSummer(1:2:14,:)=EtaU11;
ElasSummer(2:2:14,:)=Sd11;
ElasMonsoon=zeros(14,7);
ElasMonsoon(1:2:14,:)=EtaU12;
ElasMonsoon(2:2:14,:)=Sd12;
ElasWinter=zeros(14,7);
ElasWinter(1:2:14,:)=EtaU13;
ElasWinter(2:2:14,:)=Sd13;

ElasOLS=zeros(14,7);
ElasOLS(1:2:14,:)=EtaU2;
ElasOLS(2:2:14,:)=Sd2;

ElasNoSKUP=zeros(14,7);
ElasNoSKUP(1:2:14,:)=EtaU4;
ElasNoSKUP(2:2:14,:)=Sd4;

save TRIPS_Appen.mat TD* SD* State* TC TFlag SC* SFlag* SEtaU*  Elas* 
diary off

