diary TRIPS_Appen2.out
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The program that estimates welfare loss and foreign producers' gain
% assuming MC=P. See Appendix table A5 and A6
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear; format short g;

load AIDSData.mat                
%'TD' Contains data of the anti-biotics sub-segments, used for the 
% Top-level demand estimation: Segment Revenue Share, Log of Segment Price,
% Price Index for the Top Level, Log of per capita price index deflated 
% expenditure on anti-biotics

%'SD' contains data of the product groups in the Quinolone segment, used 
% for the second-level demand estimation: Product revenue share, log
% of the product price, price index for the lower level, log of per capita
% price index deflated expenditure on Quinolones; regional dummies: North,
% East, West, South; Seasonal dummies: Summer, Monsoon, Winter; the number
% of SKU in each product group; prices for the top SKUs; log of total expenditure 
% on anti-biotics

%'State' contains the random generator used for the paper
%'State_Appen' contains the random generator used for the appendix
%   specification

rand('state',State)         %Use the same random generator as in the paper

BST=300;        %Generate 300 Bootstrap samples
for j = 1:BST
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Bootstrap data
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    BS1=[]; BS2=[];
    if j == 1;                      % Obtain parameter estimate using the original sample
        BS1=TD; BS2=SD;
    else                            % for j =2:300, the bootstrap samples
        Idx = ceil( 96*rand(96,1) ); 
        for i = 1 : 8;
            Smp = TD(1+(i-1)*96:i*96,:);          % The Bootstrap sample uses the same region/period for all segment
            BS1  = [BS1;Smp(Idx,:)];                  
        end;
        for i = 1 : 7;
            Smp = SD(1+(i-1)*96:i*96,:);          % The Bootstrap sample uses the same region/period for all product group
            BS2  = [BS2;Smp(Idx,:)];                  
        end;
    end;
    
    Region=BS2(1:96,5:8); Season=BS2(1:96,9:11);
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Estimate the parameters for Upper & Lower Stage
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    TR=1;TS=0;TWin=0; %Only Region Dummy for Top level
    SR=1;SS=0;SWin=0; %Only Region Dummy for Low level
    
    [TC(:,j), TFlag(j)] = P1_UpAIDS([BS1(:,1:4),repmat([Region,Season],8,1)],...
                          TR, TS, TWin);

    SKUN = BS2(:,12); 
    tmp1=zeros(96,7); tmp1(:)=SKUN; 
    [SC(:,j), SFlag(j)] = P3_LowerAIDS([BS2(:,1:4),repmat([Region,Season],7,1)],...
                          SR, SS, SWin,[tmp1,Region(:,2:4),BS2(1:96,18)],BS2(:,13:17));
    %Lower IV: Numbers of SKU, Regional dummies, Antibiotics expenditure
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Obtain Starting Point for Counter-Factual
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    [TW(:,j),TLP(:,j),TPI(:,j),TLXP(:,j)] = P6_UpInitial([BS1(:,1:4),...
        repmat([Region,Season],8,1)],TR, TS, TWin);
    [SW(:,j),SLP(:,j),SPI(:,j),SLXP(:,j)] = P7_LowInitial([BS2(:,1:4),...
        repmat([Region,Season],7,1)],SR, SS, SWin);
    SLX(:,j)=SPI(:,j)+SLXP(:,j);
    
    for r=1:4
    %Coefficient matrix for the upper stage    
    tmp=zeros(10,8); tmp(:)=TC(1:80,j);
    if r==1                      %North
       TA=tmp(1,:)';
    elseif r==2                  %East
        TA=tmp(1,:)' + TC(81:3:104,j);
    elseif r==3                  %West
        TA=tmp(1,:)' + TC(82:3:104,j);
    elseif r==4                  %South
        TA=tmp(1,:)' + TC(83:3:104,j);
    end;    
    TG=tmp(2:9,:); TB=tmp(10,:)';
    
    t1 = zeros(6,7); t1(:) = SC(1:42,j);
    t2 = zeros(3,7); t2(:) = SC(43:end,j);
    % Coefficient matrix for the lower stage
    Coef=[t1;t2]';
    if r==1
        SA=Coef(:,1);
    elseif r==2
        SA=Coef(:,1)+Coef(:,7);
    elseif r==3
        SA=Coef(:,1)+Coef(:,8);
    elseif r==4
        SA=Coef(:,1)+Coef(:,9);
    end;    
    SB = Coef(:,6); SG = P8_Gamma(Coef(:,2:5));
    
    % SEtaU is the unconditional demand elasticity for four regions
    % MC is the marginal cost
    [TLX(r,j),TA0(r,j),TU0(r,j),SA0(r,j),SU0(r,j),SEtaU((r-1)*49+1:r*49,j),...
            MC((r-1)*7+1:r*7,j)]=P9_Base(TA,TG,TB,...
        TLP((r-1)*8+1:r*8,j),TLXP(r,j),SA,SG,SB,SLP((r-1)*7+1:r*7,j),...
        SPI(r,j),SLX(r,j),SW((r-1)*7+1:r*7,j));
    MC((r-1)*7+1:r*7,j)=exp(SLP((r-1)*7+1:r*7,j));  %set MC=P
    
    %%%%%%%%%%%%%%%%%%%% Counter-factual%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%% Product Variety: Fix Other Drugs' Prices and Expenditure  %%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    GrpN = [4;6;456;467;4567]; x0 = cell(5,1);
    tp = SLP((r-1)*7+1:r*7,j);
    x0 = {tp(4);tp(6);tp(4:6);tp([4,6:7]);tp(4:7)};
    OthLP = {tp([1:3,5:7]);tp([1:5,7]);...
        tp([1:3,7]);tp([1:3,5]); tp(1:3)};
    x1 ={0;0;zeros(3,1);zeros(3,1);zeros(4,1);};
    for i=1:5
        [x1{i},fval,Flag((r-1)*15+i,j)] = fsolve(@P10_FixP_FixX,x0{i},optimset('MaxFunEvals',2000),...
            GrpN(i),OthLP{i},SA0(r,j),SA,SG,SB,SLX(r,j),0);
    end;

    TmpP = repmat(tp,1,5);
    TmpP(4,1)=x1{1}; TmpP(6,2)=x1{2};
    TmpP(4:6,3)=x1{3};TmpP([4,6,7],4)=x1{4}; 
    TmpP(4:7,5)=x1{5};
    C_SLP((r-1)*105+1:(r-1)*105+35,j) = TmpP(:);

    %%%%%%%%%%%%%%%%%%%% Counter-factual%%%%%%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%% Fix Other Prices, Allow Expenditure to Change %%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    x2 ={0;0;zeros(3,1);zeros(3,1);zeros(4,1);};
    for i=1:5
        [x2{i},fval,Flag((r-1)*15+i+5,j)] = fsolve(@P11_FixP_ChgX,x0{i},optimset('MaxFunEvals',2000),...
            GrpN(i),OthLP{i},SA0(r,j),SA,SG,SB,TA0(r,j),TA,TG,TB,SW((r-1)*7+1:r*7,j),...
            TW((r-1)*8+1:r*8,j),TLP((r-1)*8+1:r*8,j), TLX(r,j),0);
    end;
    
    tmp = repmat(tp,1,5);
    tmp(4,1)=x2{1}; tmp(6,2)=x2{2};
    tmp(4:6,3)=x2{3};tmp([4,6,7],4)=x2{4}; 
    tmp(4:7,5)=x2{5};
    C_SLP((r-1)*105+36:(r-1)*105+70,j) = tmp(:);
    TmpP = [TmpP,tmp];
    
    %%%%%%%%%%%%%%%%%%%% Counter-factual%%%%%%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%% Allow Both Prices And Expenditure To Change %%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    x0 = SLP((r-1)*7+1:r*7,j); x0(2)=[]; LPFN=[ones(2,1)*2.763; ones(3,1)*3.4538];
    x3=zeros(6,5);
    for i=1:5
        [x3(:,i),fval,Flag((r-1)*15+i+10,j)] = fsolve(@P12_ChgP_ChgX,x0,optimset('MaxFunEvals',2000),...
            GrpN(i), LPFN(i),SA0(r,j),SA,SG,SB,TA0(r,j),TA,TG,TB,SW((r-1)*7+1:r*7,j),...
            TW((r-1)*8+1:r*8,j),TLP((r-1)*8+1:r*8,j),TLX(r,j),MC((r-1)*7+1:r*7,j),0);
    end;

    tmp = [x3(1,:);LPFN';x3(2:6,:)];
    C_SLP((r-1)*105+71:(r-1)*105+105,j) = tmp(:);
    TmpP = [TmpP,tmp];
    
    %%%%%% Create Result
    for i=1:15
        tp = TmpP(:,i);
        C_SPI((r-1)*15+i,j) = SA0(r,j) + SA' * tp + .5 * tp' * SG * tp;   
        %Lower stage counter-factual price index
        
        tpp = TLP((r-1)*8+1:r*8,j);           %upper level lnp
        tpp(8) = C_SPI((r-1)*15+i,j);         %upper stage Quin's price
        C_TPI((r-1)*15+i,j) = TA0(r,j) + TA'*tpp + .5*tpp'*TG*tpp;   %temporary upper level lnpidx

        C_TW = TA + TG*tpp + TB*(TLX(r,j) - C_TPI((r-1)*15+i,j));    %Quin's revshr
        if i<= 5
            C_SLX((r-1)*15+i,j) = SLX(r,j);
        else
            C_SLX((r-1)*15+i,j) = TLX(r,j) + log(C_TW(8));            
        end;
        % Counter-factual log expenditure on Quin
   
        lnxp = C_SLX((r-1)*15+i,j) - C_SPI((r-1)*15+i,j);
        C_SW((r-1)*105+(i-1)*7+1:(r-1)*105+i*7,j) = SA + SG * tp + SB * lnxp;
        C_SQ((r-1)*105+(i-1)*7+1:(r-1)*105+i*7,j) = ...
            exp(C_SLX((r-1)*15+i,j)) *C_SW((r-1)*105+(i-1)*7+1:(r-1)*105+i*7,j)./exp(tp);
        
        C_TLC((r-1)*15+i,j) = C_TPI((r-1)*15+i,j) + TU0(r,j)*prod(exp(tpp).^TB);
        WelfTop((r-1)*15+i,j) = exp(C_TLC((r-1)*15+i,j))-exp(TLX(r,j));
    end;
    end;
end;
    
%%%%%%%%%%%%%%ORGANIZE RESULTS AND CREATE TABLES %%%%%%%%%%%%%%%%
%% Table A5: Consumer Welfare Loss; 
%% Table A6: Profit gain to foreign producers
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[WelfLoss,tmp1,PiChg_F,tmp2]=P16_TableCV_PiChg(Flag,WelfTop,SW,SLX,SLP,MC,C_SLP,C_SQ);
PiChg_F(:,1:2)=0;

save TRIPS_Appen2.mat  TD* SD* State* WelfLoss PiChg_F Flag WelfTop SW SLX SLP MC C_SLP C_SQ TC TFlag SC SFlag
diary off
